@@ -50,39 +50,42 @@ def get_run_id(output_dir):
         return output_dir
 
 def prerun_error_check():
-    if len(sys.argv) < 6 or len(sys.argv) > 7:
-        arg_err_str = "Incorrect number of arguments provided. Required arguments: \n\t-Input Directory \n\t-Output Directory \n\t-Timeout(in minutes) \n\t-Number of CPU cores \n\t-D3M Problem Path (please refer to AutonML's documentation for more details \n\n Optional arguments \n\t-D3M Static directory: stores weight files\n"
+    if len(sys.argv) < 7 or len(sys.argv) > 8:
+        arg_err_str = "Incorrect number of arguments provided. Required arguments (in order): \n\t-Run type (fit/fit-produce/produce) \n\t-Input Directory \n\t-Output Directory \n\t-Timeout(in minutes) \n\t-Number of CPU cores \n\t-D3M Problem Path (please refer to AutonML's documentation for more details \n\n Optional arguments \n\t-D3M Static directory: stores weight files\n"
         raise ArgumentError(arg_err_str)
 
-    if not os.path.exists(sys.argv[1]):
-        raise FileNotFoundError("Input directory does not exist")
+    if sys.argv[1] != 'fit' and sys.argv[1] != 'fit-produce' and sys.argv[1] != 'produce':
+        raise ArgumentError(f"Run type argument is invalid. It must either be fit, fit-produce, or produce. Argument provided by user for run-type: {sys.argv[1]}")
 
-    if not os.path.exists(sys.argv[5]):
-        raise FileNotFoundError("Problem Path directory does not exist")
+    if not os.path.exists(sys.argv[2]):
+        raise FileNotFoundError(f"Input directory provided ({sys.argv[2]}) does not exist")
 
-    if len(sys.argv) == 7:
-        if not os.path.exists(sys.argv[6]):
-            raise FileNotFoundError("Static directory does not exist")
+    if not os.path.exists(sys.argv[6]):
+        raise FileNotFoundError(f"Problem Path file provided ({sys.argv[6]}) does not exist")
+
+    if len(sys.argv) == 8:
+        if not os.path.exists(sys.argv[7]):
+            raise FileNotFoundError(f"Static directory provided ({sys.argv[7]}) does not exist")
 
 def main_run():
     '''Main API to invoke complete AutonML pipeline'''
 
-    if not os.path.exists(sys.argv[2]):
-        logging.warning(f"Output directory does not exist, creating Output directory at path: {sys.argv[2]}")
+    if not os.path.exists(sys.argv[3]):
+        logging.warning(f"Output directory does not exist, creating Output directory at path: {sys.argv[3]}")
 
-        output_path = Path(sys.argv[2])
+        output_path = Path(sys.argv[3])
 
         if not output_path.parent.exists():
             # TODO (vedant) : should parent directories be created recursively too?
-            raise FileNotFoundError(f"Parent directory {output_path.parent()} for provided output path: {sys.argv[2]} does not exist. Please recheck that the provided parent path is correct")
+            raise FileNotFoundError(f"Parent directory {output_path.parent()} for provided output path: {sys.argv[3]} does not exist. Please recheck that the provided parent path is correct")
         else:
-            os.mkdir(sys.argv[2])
+            os.mkdir(sys.argv[3])
 
     # Perform a preliminary error check to ensure number of arguments and directories supplied are correct
     prerun_error_check()
 
     # Remove all files in output directory
-    output_dir = sys.argv[2]
+    output_dir = sys.argv[3]
     for search_dir in os.listdir(output_dir):
         search_dir_path = os.path.join(output_dir, search_dir)
         shutil.rmtree(search_dir_path)
@@ -92,10 +95,10 @@ def main_run():
 
     # Fit and evaluate across searched pipelines
     # TODO (vedant) : error checks here
-    fit_and_evaluate(output_dir)
+    run_pipeline(output_dir, sys.argv[1])
 
     # Save environment variables in a file
-    search_dir_path = get_run_id(sys.argv[2])
+    search_dir_path = get_run_id(sys.argv[3])
     filepath = os.path.join(search_dir_path, 'environment_variables.json')
     
     env_dict = {}
@@ -112,7 +115,7 @@ def main_run():
     garbage_collect()
 
 
-def fit_and_evaluate(output_dir):
+def run_pipeline(output_dir, run_method):
 
     # TODO (vedant) : Error checking on valid directory paths?
     # Code to score the output, and write to the $D3MOUTPUTDIR directory
@@ -124,18 +127,25 @@ def fit_and_evaluate(output_dir):
             jsonfile_path = os.path.join(pipeline_dir_path, jsonfile)
             prediction_name = jsonfile.replace('.json', '')
             logging.critical(f'Evaluating over JSON File {idx+1}/{len(os.listdir(pipeline_dir_path))}: {jsonfile_path}\n')
+            
+            if run_method == 'fit-produce':
+                p = subprocess.Popen([sys.executable, '-m', 'd3m', 'runtime', '-v',
+                                    os.environ['D3MSTATICDIR'], 'fit-produce', '-p',
+                                    jsonfile_path, '-r', os.path.join(os.environ['D3MINPUTDIR'], 'TRAIN/problem_TRAIN/problemDoc.json'),
+                                    '-i', os.path.join(os.environ['D3MINPUTDIR'], 'TRAIN/dataset_TRAIN/datasetDoc.json'), '-t',
+                                    os.path.join(os.environ['D3MINPUTDIR'], 'TEST/dataset_TEST/datasetDoc.json'), '-o',
+                                    os.path.join(search_dir_path, 'predictions', f'{prediction_name}.predictions.csv')], 
+                                    stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
-            p = subprocess.Popen([sys.executable, '-m', 'd3m', 'runtime', '-v',
-                                  os.environ['D3MSTATICDIR'], 'fit-produce', '-p',
-                                  jsonfile_path, '-r', os.path.join(os.environ['D3MINPUTDIR'], 'TRAIN/problem_TRAIN/problemDoc.json'),
-                                  '-i', os.path.join(os.environ['D3MINPUTDIR'], 'TRAIN/dataset_TRAIN/datasetDoc.json'), '-t',
-                                  os.path.join(os.environ['D3MINPUTDIR'], 'TEST/dataset_TEST/datasetDoc.json'), '-o',
-                                  os.path.join(search_dir_path, 'predictions', f'{prediction_name}.predictions.csv')], 
-                                  stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            elif run_method == 'fit':
+                p = subprocess.Popen([sys.executable, '-m', 'd3m', 'runtime', '-v',
+                                    os.environ['D3MSTATICDIR'], 'fit', '-p',
+                                    jsonfile_path, '-r', os.path.join(os.environ['D3MINPUTDIR'], 'TRAIN/problem_TRAIN/problemDoc.json'),
+                                    '-i', os.path.join(os.environ['D3MINPUTDIR'], 'TRAIN/dataset_TRAIN/datasetDoc.json')], 
+                                    stderr=subprocess.PIPE)
 
-            output, error = p.communicate()
+            _, error = p.communicate()
             if p.returncode != 0:
-                print(output.decode())
                 raise RuntimeError(error.decode())
 
             # Generate code that converts JSON to python code
@@ -155,14 +165,14 @@ def main_search():
     # variables
     logging.info('RUNNING SEARCH')
 
-    os.environ['D3MINPUTDIR'] = sys.argv[1]
-    os.environ['D3MOUTPUTDIR'] = sys.argv[2]
-    os.environ['D3MTIMEOUT'] = sys.argv[3]
-    os.environ['D3MCPU'] = sys.argv[4]
-    os.environ['D3MPROBLEMPATH'] = sys.argv[5]
+    os.environ['D3MINPUTDIR'] = sys.argv[2]
+    os.environ['D3MOUTPUTDIR'] = sys.argv[3]
+    os.environ['D3MTIMEOUT'] = sys.argv[4]
+    os.environ['D3MCPU'] = sys.argv[5]
+    os.environ['D3MPROBLEMPATH'] = sys.argv[6]
 
-    if len(sys.argv) == 7:
-        os.environ['D3MSTATICDIR'] = sys.argv[6]
+    if len(sys.argv) == 8:
+        os.environ['D3MSTATICDIR'] = sys.argv[7]
     else:
         os.environ['D3MSTATICDIR'] = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'static')
 
