@@ -165,7 +165,7 @@ def evaluate_solution_score(inputs, solution, primitives, metric, posLabel, sol_
     Scores each potential solution
     Runs in a separate process
     """
-    print("Evaluating ", solution.id)
+    print("Evaluating pipeline: ", solution.id)
 
     (score, optimal_params) = solution.score_solution(inputs=inputs, metric=metric, posLabel=posLabel,
                                 primitive_dict=primitives, solution_dict=sol_dict, mode=training_preds_dir)
@@ -177,7 +177,7 @@ def fit_solution(inputs, testdata, solution, primitives, outputDir, problem_desc
     Fits each potential solution
     Runs in a separate process
     """
-    print("Fitting ", solution.id)
+    print("Fitting pipeline: ", solution.id)
 
     #output = solution.fit(inputs=inputs, solution_dict=None)
     #output = solution.produce(inputs=testdata, solution_dict=None)
